@@ -167,7 +167,7 @@ KAlgebra::KAlgebra(QWidget *parent)
     connect(c_results, SIGNAL(paste(QString)), c_exp, SLOT(insertText(QString)));
     connect(c_variables, &QAbstractItemView::clicked, this, &KAlgebra::edit_var);
     ////////menu
-    c_menu = menuBar()->addMenu(i18n("C&onsole"));
+    c_menu = menuBar()->addMenu(i18n("C&alculator"));
     
     c_menu->addAction(QIcon::fromTheme(QStringLiteral("document-open")), i18nc("@item:inmenu", "&Load Script..."),
                         this, SLOT(loadScript()), Qt::CTRL+Qt::Key_L);
@@ -573,9 +573,9 @@ void KAlgebra::set_solid()
 void KAlgebra::save3DGraph()
 {
 #ifdef HAVE_OPENGL
-    QString path = QFileDialog::getSaveFileName(this, QString(), QString(), i18n("PNG File (*.png);;PDF Document(*.pdf);;X3D Document (*.x3d)"));
+    QString path = QFileDialog::getSaveFileName(this, QString(), QString(), i18n("PNG File (*.png);;PDF Document(*.pdf);;X3D Document (*.x3d);;STL Document (*.stl)"));
     if(!path.isEmpty()) {
-        if(path.endsWith(QLatin1String(".x3d"))) {
+        if(path.endsWith(QLatin1String(".x3d")) || path.endsWith(QLatin1String(".stl"))) {
             m_graph3d->exportSurfaces(path);
         } else if(path.endsWith(QLatin1String(".pdf"))) {
             QPixmap px = m_graph3d->renderPixmap();
